from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bits:
	"""Bits commands group definition. 3 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bits", core, parent)

	@property
	def cataloge(self):
		"""cataloge commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cataloge'):
			from .Bits_.Cataloge import Cataloge
			self._cataloge = Cataloge(self._core, self._base)
		return self._cataloge

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .Bits_.All import All
			self._all = All(self._core, self._base)
		return self._all

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Bits_.Count import Count
			self._count = Count(self._core, self._base)
		return self._count

	def clone(self) -> 'Bits':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Bits(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
