from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tsensitivity:
	"""Tsensitivity commands group definition. 25 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tsensitivity", core, parent)

	@property
	def voip(self):
		"""voip commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_voip'):
			from .Tsensitivity_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	@property
	def audioOutput(self):
		"""audioOutput commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioOutput'):
			from .Tsensitivity_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	@property
	def fdeviation(self):
		"""fdeviation commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_fdeviation'):
			from .Tsensitivity_.Fdeviation import Fdeviation
			self._fdeviation = Fdeviation(self._core, self._base)
		return self._fdeviation

	@property
	def pdeviation(self):
		"""pdeviation commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_pdeviation'):
			from .Tsensitivity_.Pdeviation import Pdeviation
			self._pdeviation = Pdeviation(self._core, self._base)
		return self._pdeviation

	@property
	def modDepth(self):
		"""modDepth commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_modDepth'):
			from .Tsensitivity_.ModDepth import ModDepth
			self._modDepth = ModDepth(self._core, self._base)
		return self._modDepth

	def clone(self) -> 'Tsensitivity':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tsensitivity(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
